==> digikam-3.2.0.tar.bz2: digikam-3.2.0/extra/kipi-plugins/common/libkipiplugins/kipiplugins.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Name=KIPI Plugins
Name[ast]=Complementos KIPI
Name[bg]=Приставки KIPI
Name[bs]=KIPI Plugins
Name[ca]=Connectors Kipi
Name[ca@valencia]=Connectors Kipi
Name[cs]=Moduly KIPI
Name[da]=KIPI-plugins
Name[de]=KIPI-Module
Name[el]=Πρόσθετα KIPI
Name[en_GB]=KIPI Plugins
Name[es]=Complementos KIPI
Name[et]=KIPI pluginad
Name[eu]=KIPIren pluginak
Name[fi]=Kipi-liitännäiset
Name[fr]=Modules externes KIPI
Name[ga]=Breiseáin KIPI
Name[gl]=Engadidos de KIPI
Name[hu]=KIPI bővítmények
Name[is]=KIPI íforrit
Name[it]=Estensioni di KIPI
Name[km]=កម្មវិធី​ជំនួយ KIPI
Name[lt]=KIPI papildiniai
Name[lv]=KIPI spraudņi
Name[nb]=KIPI programtillegg
Name[nds]=KIPI-Modulen
Name[nl]=KIPI-plugins
Name[pa]=KIPI ਪਲੱਗਇਨ
Name[pl]=Wtyczki KIPI
Name[pt]='Plugins' do KIPI
Name[pt_BR]=Plugins Kipi
Name[ro]=Extensii KIPI
Name[ru]=Расширения KIPI
Name[sk]=Zásuvné moduly KIPI
Name[sl]=Vstavki KIPI
Name[sq]=Pluginët KIPI
Name[sv]=KIPI-insticksprogram
Name[th]=ส่วนเสริมของ Kipi
Name[tr]=Kipi Eklentileri
Name[ug]=KIPI قىستۇرمىلىرى
Name[uk]=Додатки KIPI
Name[x-test]=xxKIPI Pluginsxx
Name[zh_CN]=KIPI 插件
Name[zh_TW]=KIPI 外掛工具
Comment=KDE Image Plugins Interface
Comment[ast]=Interfaz de complementos d'imaxe de KDE
Comment[bg]=Интерфейс на KDE за приставки за изображения
Comment[bs]=KDE interfejs za priključke koji obrađuju slike
Comment[ca]=Interfície de connectors d'imatge del KDE
Comment[ca@valencia]=Interfície de connectors d'imatge del KDE
Comment[cs]=Rozhraní modulů pro práci s obrázky v KDE
Comment[da]=KDE grænseflade til billed-plugins (KIPI)
Comment[de]=KDE-Bildbearbeitungsschnittstelle
Comment[el]=Διεπαφή πρόσθετων εικόνας KDE
Comment[en_GB]=KDE Image Plugins Interface
Comment[es]=Interfaz de complementos para imágenes de KDE
Comment[et]=KDE pildipluginate liides
Comment[eu]=KDEren Irudientzako Pluginen Interfazea
Comment[fr]=Module externe interface de KDE Image
Comment[gl]=Interface para os engadidos de imaxe de KDE
Comment[hu]=KDE kép bővítmények felület
Comment[is]=KDE Image Plugins Interface myndvinnsluviðmót
Comment[it]=Interfaccia delle estensioni per le immagini di KDE
Comment[km]=ចំណុច​ប្រទាក់​កម្មវិធី​ជំនួយ​រូបភាព​របស់ KDE
Comment[lt]=KDE vaizdo papildinių sąsaja
Comment[lv]=KDE attēlu spraudņu saskarne
Comment[nb]=Grensesnitt til KDE-programtillegg for bilder
Comment[nds]=KDE-Koppelsteed för Bildmodulen
Comment[nl]=Interface voor KDE afbeeldingsplugins
Comment[pa]=KDE ਈਮੇਜ਼ ਪਲੱਗਇਨ ਇੰਟਰਫੇਸ
Comment[pl]=Interfejs dla wtyczek obrazów KDE
Comment[pt]=Interface de 'Plugins' de Imagens do KDE
Comment[pt_BR]=Interface de plugins de imagem do KDE
Comment[ro]=KIPI (KDE Image Plugins Interface)
Comment[ru]=Интерфейс расширений для работы с изображениями для KDE
Comment[sk]=KDE rozhranie pre zásuvné moduly obrázkov
Comment[sl]=Vmesnik vstavkov za slike za KDE
Comment[sq]=Ndërfaqja e Pluginëve të Imazhit KDE
Comment[sv]=KDE:s gränssnitt för bildinsticksprogram
Comment[th]=ส่วนติดต่อส่วนเสริมการจัดการภาพแบบต่าง ๆ ของ KDE
Comment[tr]=KDE Resim Eklentileri Arayüzü
Comment[ug]=KDE سۈرەت قىستۇرمىلىرى ئارايۈزى
Comment[uk]=Інтерфейс додатків KDE для роботи з зображеннями
Comment[x-test]=xxKDE Image Plugins Interfacexx
Comment[zh_CN]=KDE 图像插件接口
Comment[zh_TW]=KDE 影像外掛介面
X-DocPath=kipi-plugins/index.html
Categories=Qt;KDE;Graphics;
NoDisplay=true
Type=Application
# Exec="" is necessary to get this entry to show up in khelpcenter
Exec=""
Icon=kipi-logo

[X-KipiPlugins Entry]
Version=${KIPIPLUGINS_VERSION_STRING}

==> digikam_3.5.0.orig.tar.bz2: digikam-3.5.0/extra/kipi-plugins/common/libkipiplugins/kipiplugins.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Name=KIPI Plugins
Name[ast]=Complementos KIPI
Name[bg]=Приставки KIPI
Name[bs]=KIPI Plugins
Name[ca]=Connectors Kipi
Name[ca@valencia]=Connectors Kipi
Name[cs]=Moduly KIPI
Name[da]=KIPI-plugins
Name[de]=KIPI-Module
Name[el]=Πρόσθετα KIPI
Name[en_GB]=KIPI Plugins
Name[es]=Complementos KIPI
Name[et]=KIPI pluginad
Name[eu]=KIPIren pluginak
Name[fi]=Kipi-liitännäiset
Name[fr]=Modules externes KIPI
Name[ga]=Breiseáin KIPI
Name[gl]=Engadidos de KIPI
Name[hu]=KIPI bővítmények
Name[is]=KIPI íforrit
Name[it]=Estensioni di KIPI
Name[km]=កម្មវិធី​ជំនួយ KIPI
Name[lt]=KIPI papildiniai
Name[lv]=KIPI spraudņi
Name[nb]=KIPI programtillegg
Name[nds]=KIPI-Modulen
Name[nl]=KIPI-plugins
Name[pa]=KIPI ਪਲੱਗਇਨ
Name[pl]=Wtyczki KIPI
Name[pt]='Plugins' do KIPI
Name[pt_BR]=Plugins Kipi
Name[ro]=Extensii KIPI
Name[ru]=Расширения KIPI
Name[sk]=Zásuvné moduly KIPI
Name[sl]=Vstavki KIPI
Name[sq]=Pluginët KIPI
Name[sv]=KIPI-insticksprogram
Name[th]=ส่วนเสริมของ Kipi
Name[tr]=Kipi Eklentileri
Name[ug]=KIPI قىستۇرمىلىرى
Name[uk]=Додатки KIPI
Name[x-test]=xxKIPI Pluginsxx
Name[zh_CN]=KIPI 插件
Name[zh_TW]=KIPI 外掛工具
Comment=KDE Image Plugins Interface
Comment[ast]=Interfaz de complementos d'imaxe de KDE
Comment[bg]=Интерфейс на KDE за приставки за изображения
Comment[bs]=KDE interfejs za priključke koji obrađuju slike
Comment[ca]=Interfície de connectors d'imatge del KDE
Comment[ca@valencia]=Interfície de connectors d'imatge del KDE
Comment[cs]=Rozhraní modulů pro práci s obrázky v KDE
Comment[da]=KDE grænseflade til billed-plugins (KIPI)
Comment[de]=KDE-Bildbearbeitungsschnittstelle
Comment[el]=Διεπαφή πρόσθετων εικόνας KDE
Comment[en_GB]=KDE Image Plugins Interface
Comment[es]=Interfaz de complementos para imágenes de KDE
Comment[et]=KDE pildipluginate liides
Comment[eu]=KDEren Irudientzako Pluginen Interfazea
Comment[fr]=Interface de module externe d'images de KDE
Comment[gl]=Interface para os engadidos de imaxe de KDE
Comment[hu]=KDE kép bővítmények felület
Comment[is]=KDE Image Plugins Interface myndvinnsluviðmót
Comment[it]=Interfaccia delle estensioni per le immagini di KDE
Comment[km]=ចំណុច​ប្រទាក់​កម្មវិធី​ជំនួយ​រូបភាព​របស់ KDE
Comment[lt]=KDE vaizdo papildinių sąsaja
Comment[lv]=KDE attēlu spraudņu saskarne
Comment[nb]=Grensesnitt til KDE-programtillegg for bilder
Comment[nds]=KDE-Koppelsteed för Bildmodulen
Comment[nl]=Interface voor KDE afbeeldingsplugins
Comment[pa]=KDE ਈਮੇਜ਼ ਪਲੱਗਇਨ ਇੰਟਰਫੇਸ
Comment[pl]=Interfejs dla wtyczek obrazów KDE
Comment[pt]=Interface de 'Plugins' de Imagens do KDE
Comment[pt_BR]=Interface de plugins de imagem do KDE
Comment[ro]=KIPI (KDE Image Plugins Interface)
Comment[ru]=Интерфейс расширений для работы с изображениями для KDE
Comment[sk]=KDE rozhranie pre zásuvné moduly obrázkov
Comment[sl]=Vmesnik vstavkov za slike za KDE
Comment[sq]=Ndërfaqja e Pluginëve të Imazhit KDE
Comment[sv]=KDE:s gränssnitt för bildinsticksprogram
Comment[th]=ส่วนติดต่อส่วนเสริมการจัดการภาพแบบต่าง ๆ ของ KDE
Comment[tr]=KDE Resim Eklentileri Arayüzü
Comment[ug]=KDE سۈرەت قىستۇرمىلىرى ئارايۈزى
Comment[uk]=Інтерфейс додатків KDE для роботи з зображеннями
Comment[x-test]=xxKDE Image Plugins Interfacexx
Comment[zh_CN]=KDE 图像插件接口
Comment[zh_TW]=KDE 影像外掛介面
X-DocPath=kipi-plugins/index.html
Categories=Qt;KDE;Graphics;
NoDisplay=true
Type=Application
# Exec="" is necessary to get this entry to show up in khelpcenter
Exec=""
Icon=kipi-logo

[X-KipiPlugins Entry]
Version=${KIPIPLUGINS_VERSION_STRING}
